==> haskell-git-lfs-1.2.5-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-git-lfs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 git-lfs
version:              1.2.5
visibility:           public
id:                   git-lfs-1.2.5-Ct02Rp4E2hbBwANgauBHG0
key:                  git-lfs-1.2.5-Ct02Rp4E2hbBwANgauBHG0
license:              AGPL-3.0-only
copyright:            2019 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             git-lfs protocol
description:          An implementation of the git-lfs protocol.
category:             Network
abi:                  fb5fb18e44f24eab696b99c0ef6352d0
exposed:              True
exposed-modules:      Network.GitLFS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-git-lfs
hs-libraries:         HSgit-lfs-1.2.5-Ct02Rp4E2hbBwANgauBHG0
depends:
    aeson-2.1.2.1-F8ZePgr6g4xL6kF4wsQx0x base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-B227KtiOix4GTDgvxk3FBB
    containers-0.6.7 http-client-0.7.19-LRfftiQ6YWX88xW4fFXEK8
    http-types-0.12.4-Hsb6Y5xUgLKEUlBrgYk3WM
    network-uri-2.6.4.2-8swvJWOy75N7pbfI8WzbN text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-git-lfs/html/git-lfs.haddock
haddock-html:         /usr/share/doc/haskell-git-lfs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-git-lfs-1.2.5-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-git-lfs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 git-lfs
version:              1.2.5
visibility:           public
id:                   git-lfs-1.2.5-LrNO6NZpnMf9tTVV5B6ldG
key:                  git-lfs-1.2.5-LrNO6NZpnMf9tTVV5B6ldG
license:              AGPL-3.0-only
copyright:            2019 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             git-lfs protocol
description:          An implementation of the git-lfs protocol.
category:             Network
abi:                  6f054983e391891f75d2cccb340d73d2
exposed:              True
exposed-modules:      Network.GitLFS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-git-lfs
hs-libraries:         HSgit-lfs-1.2.5-LrNO6NZpnMf9tTVV5B6ldG
depends:
    aeson-2.1.2.1-IZ8jLcnEISD7S5Vyf2Tehm base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-3FuXchFPXBfLVJKu7fam1O
    containers-0.6.7 http-client-0.7.19-B8l1xqF9CzrAQJibWsxIAb
    http-types-0.12.4-9GhteoJuOlZ3ATAYoIbhkU
    network-uri-2.6.4.2-BPG1Yj05GAIIauIotQ4jTb text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-git-lfs/html/git-lfs.haddock
haddock-html:         /usr/share/doc/haskell-git-lfs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
